/*
	ecmdline.c -- command line parser for etrnquery
	(C) Wouter Coene, 1999

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#define WANT_UNISTD
#include "config-wrap.h"
#include <getopt.h>

#define CMDLINE_HAVE_DATA
#include "ecmdline.h"
#include "mailer.h"
#include "omta.h"
#include "readconf.h"
#include "lib.h"
#include "log.h"

char *myself=NULL;
int mode;

/***
 * help
 * Write a usage message to the standard output.
 */
void help()
{
	printf("Usage:\t%s [options]\n\n",myself);
	printf("     -q,  --query\tdo the query\n");
	printf("     -C,  --config\tspecify config file\n\n");

	printf("     -h,  --help\tshow this information\n");
	printf("     -v,  --version\toutput version and license info\n");
	printf("     -D,  --default\tshow compile-time defaults\n\n");

	printf("Please report bugs to <" OMTA_LIST ">\n");
}

/***
 * short_help
 * Write a GNU-style short help message to the standard output.
 */
void short_help()
{
	printf("Try `%s --help' for more information.\n",myself);
}

/***
 * short_version
 * Write a single-line version string to the standard output.
 */
void short_version()
{
	printf(NAME "-etrnquery " VERSION ", by the OMTA people <" OMTA_LIST ">\n");
}

/***
 * version
 * Write the full version number and license information to the
 * standard output.
 */
void version()
{
	short_version();
	printf("Get it at " OMTA_URI " \n\n");

	printf("This program is free software; you can redistribute it and/or modify\n");
	printf("it under the terms of the GNU General Public License as published by\n");
	printf("the Free Software Foundation; either version 2 of the License, or\n");
	printf("(at your option) any later version.\n\n");

	printf("This program is distributed in the hope that it will be useful,\n");
	printf("but WITHOUT ANY WARRANTY; without even the implied warranty of\n");
	printf("MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n");
	printf("GNU General Public License for more details.\n\n");

	printf("You should have received a copy of the GNU General Public License\n");
	printf("along with this program. If not, write to the Free Software\n");
	printf("Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.\n");
}

/***
 * cmdline
 * Parse the command line.
 */
int cmdline(int argc, char *argv[])
{
	int opt;
	int option_index=0;
	int ok;

	log_enter();

	if (myself==NULL)
		myself=strdup(argv[0]);

	mode=MODE_QUERY;

	while ((opt=getopt_long(argc, argv, SHORT_OPTIONS, long_options, &option_index))!=-1) {
		ok=FALSE;
		switch(opt) {
			case 'h':
				mode=MODE_HELP;
				break;

			case 'v':
				mode=MODE_VERSION;
				break;

			case 'q':
				mode=MODE_QUERY;
				break;

			case 'C':
				if (conf_global!=NULL)
					free(conf_global);
				conf_global=strdup(optarg);
				break;				                                                                                                        

			case 'D':
				mode=MODE_DEFAULTS;
				break;

			case '?':
				mode=MODE_SHORTHELP;
				break;
		}
		if (mode>=MODE_NOMODE)
			break;
	}

	log_leave();

	return mode;
}

/* end ecmdline.c */
